==> cuor-order-chaining-consumer-1.3.0.tgz: package/src/conifg/index.ts <==
import { env } from "./env";
import { name, version as appVersion } from "../../package.json";

export const APP_BASE_NAME = env.APP_NAME;
export const APP_NAME = `${env.DEPLOYMENT_ENVIRONMENT}-${APP_BASE_NAME}`;
export const DEPLOYMENT_ENVIRONMENT = env.DEPLOYMENT_ENVIRONMENT;
export const AUTH_URL = env.AUTH_URL;
export const AUTH_CLIENT_ID = env.AUTH_CLIENT_ID;
export const AUTH_CLIENT_SECRET = env.AUTH_CLIENT_SECRET;
export const AUD_USX_DATA_BRIDGE = env.AUD_USX_DATA_BRIDGE;
export const IS_LOCAL = env.DEPLOYMENT_ENVIRONMENT === "local";
export const IS_PRODUCTION = env.DEPLOYMENT_ENVIRONMENT === "prod";
export const KAFKA_BOOTSTRAP_SERVERS = env.KAFKA_BOOTSTRAP_SERVERS.split(",") || [];
export const KAFKA_GROUP_ID = IS_LOCAL
  ? `${env.DEPLOYMENT_ENVIRONMENT}-${env.APP_NAME}-${Date.now()}`
  : `${env.DEPLOYMENT_ENVIRONMENT}-${name}`;
export const KAFKA_PASSWORD = env.KAFKA_PASSWORD;
export const KAFKA_SASL_MECHANISM = env.KAFKA_SASL_MECHANISM;
export const KAFKA_SOURCE_TOPIC = env.KAFKA_SOURCE_TOPIC_NAME;
export const KAFKA_USERNAME = env.KAFKA_USERNAME;
export const LOG_LEVEL = env.LOGGER_LEVEL;
export const LOG_PAYLOAD_ORDER_NUMBERS = env.LOG_PAYLOAD_ORDER_NUMBERS.split(",") || [];
export const MISSION_MANAGEMENT_API_URL = env.MISSION_MANAGEMENT_API_URL;
export const ORDER_CHAINING_PERMISSIONS = ["can_create_orders"];
export const SHOULD_PROCESS_ORDER_CHAINING = env.SHOULD_PROCESS_ORDER_CHAINING;
export const TIMEZONE_OFFSET = env.TIMEZONE_OFFSET;
export const USX_DATA_BRIDGE_API_KEY = env.USX_DATA_BRIDGE_API_KEY;
export const USX_DATA_BRIDGE_API_URL = env.USX_DATA_BRIDGE_API_URL;
export const VERSION = appVersion;

==> cuor-order-chaining-consumer-1.5.1.tgz: package/src/conifg/index.ts <==
import { env } from "./env";
import { name, version as appVersion } from "../../package.json";

export const APP_BASE_NAME = env.APP_NAME;
export const APP_NAME = `${env.DEPLOYMENT_ENVIRONMENT}-${APP_BASE_NAME}`;
export const DEPLOYMENT_ENVIRONMENT = env.DEPLOYMENT_ENVIRONMENT;
export const AUTH_URL = env.AUTH_URL;
export const AUTH_CLIENT_ID = env.AUTH_CLIENT_ID;
export const AUTH_CLIENT_SECRET = env.AUTH_CLIENT_SECRET;
export const GATEWAY_URL = env.GATEWAY_URL;
export const IS_LOCAL = env.DEPLOYMENT_ENVIRONMENT === "local";
export const IS_PRODUCTION = env.DEPLOYMENT_ENVIRONMENT === "prod";
export const KAFKA_BOOTSTRAP_SERVERS = env.KAFKA_BOOTSTRAP_SERVERS.split(",") || [];
export const KAFKA_GROUP_ID = IS_LOCAL
  ? `${env.DEPLOYMENT_ENVIRONMENT}-${env.APP_NAME}-${Date.now()}`
  : `${env.DEPLOYMENT_ENVIRONMENT}-${name}`;
export const KAFKA_PASSWORD = env.KAFKA_PASSWORD;
export const KAFKA_SASL_MECHANISM = env.KAFKA_SASL_MECHANISM;
export const KAFKA_SOURCE_TOPIC = env.KAFKA_SOURCE_TOPIC_NAME;
export const KAFKA_USERNAME = env.KAFKA_USERNAME;
export const LOG_LEVEL = env.LOGGER_LEVEL;
export const LOG_PAYLOAD_ORDER_NUMBERS = env.LOG_PAYLOAD_ORDER_NUMBERS.split(",") || [];
export const MISSION_MANAGEMENT_API_URL = env.MISSION_MANAGEMENT_API_URL;
export const ORDER_CHAINING_PERMISSIONS = "can_create_orders can_create_missions can_view_loads can_view_all_missions";
export const SHOULD_PROCESS_ORDER_CHAINING = env.SHOULD_PROCESS_ORDER_CHAINING;
export const TIMEZONE_OFFSET = env.TIMEZONE_OFFSET;
export const USX_DATA_BRIDGE_API_URL = env.USX_DATA_BRIDGE_API_URL;
export const VERSION = appVersion;
